
## Script edited on Tuesday 8th November 2020
## Computation of selection response in the 28th generation (last generation)
## and percentage (%) of does correctly selected according to (g)EBV within each simulation and imputation scenario.

library(ggplot2); library("dplyr")

getwd(); options(max.print =100000000); options(width = 10000)
options (scipen = 999) # Disable scientific notation options

pathway_1 <- "/media/samuel/ONE_PIECE/2021_GS_simulation/GAMMA/"
pathway_2 <- "/media/samuel/ONE_PIECE/2021_GS_simulation/Response_selection_last_gene/"
model <- c(5,44)

id_simul = seq(1,36,1)
id_genom = seq(1,9,1)

rs_candidate=data.frame()
x = 0 ## count

for (w in model) {
  ## system(paste('cd ',pathway,'QTN_',w,'Folder_Impute',sep = ""),wait = TRUE)
  setwd(paste(pathway_1,'QTN_',w,'/gEBV_29th_cg/',sep = "")); getwd()
  
  for(m in id_simul){
    
    evaluated <- read.table(paste("genom_",m,"/evaluated_animals_",m,".txt",sep = ""),header = TRUE)
    dim(evaluated)
    
    for (h in id_genom) {
      
      data_EBV <- read.table(paste("genom_",m,"/scene_bv_",h,"/data_real_estimate_EVB_simul_",m,"_scen_",h,"_.txt",sep = ""),header = TRUE)
      head(data_EBV); dim(data_EBV); tail(data_EBV); str(data_EBV)
      
      nrow(data_EBV[data_EBV$Generation==28,])
      
      data_EBV <- data_EBV[data_EBV$Generation==28,] # EBV data of last generation (the 28th generation)
      #  data_EBV <- data_EBV[match(evaluated$animal28,data_EBV$animal_ID),]  # it is the same as the last line.
      
      mean(data_EBV$gvGammUnres1)
      x = x +1
      
      rs_candidate[x,1] <- m  # number of simulation
      rs_candidate[x,2] <- ifelse(h<9,h,"BLUP") # scenario or imputation esttrategy
      rs_candidate[x,3] <- paste('QTN_',w,sep = "") # QTN model
      rs_candidate[x,4] <- round(mean(data_EBV$gvGammUnres1),digits = 6)  # true genetic value mean of the last generation
      
      tmp = data_EBV[order(data_EBV$EBV,decreasing = TRUE),]
         
      rs_candidate[x,5] <- round(mean(tmp[1:300,"gvGammUnres1"]),digits = 6)
      # true genetic value mean of the first 300 animals selected
      
      rs_candidate[x,6] <- rs_candidate[x,5] - rs_candidate[x,4] # Response to selection given a scenario.
      
      selected_by_real_value <- data_EBV[order(data_EBV$gvGammUnres1,decreasing = TRUE)[1:300],"animal_ID"]
      selected_by_scena <- data_EBV[order(data_EBV$EBV,decreasing = TRUE)[1:300],"animal_ID"] 

      animal_selected_correctly = length(na.omit(match(selected_by_scena,selected_by_real_value)))
      
      rs_candidate[x,7] <- animal_selected_correctly  # Number of correctly selecetd animals.
      
      rs_candidate[x,8] <- round(100*animal_selected_correctly/length(selecetd_by_real_value),digits = 4)
    }
  }
}

colnames(rs_candidate)=c("Simulation","Scenario","Number_QTN","Real_GV_mean_of_all_population_animal","GV_mean_of_300_animals_selected","Response_to_selection",
                     "Correctly_selected_animals(CSA)","Percentage_of_CSA")
title=paste("GV_animals_selected_by_scenarios_data",".txt",sep="")
write.table(rs_candidate,file = paste(pathway_2,title,sep = ""),sep = "\t",col.names = TRUE,row.names = FALSE,quote = FALSE)

##### Edit file ####
rs_candidate=read.table(file = paste(pathway_2,title,sep = ""),header = TRUE)

rs_candidate$Scenario <- as.factor(as.character(rs_candidate$Scenario))
rs_candidate$Response_to_selection <- as.numeric(as.character(rs_candidate$Response_to_selection))
rs_candidate$Correctly_selected_animals.CSA. <- as.numeric(as.character(rs_candidate$Correctly_selected_animals.CSA.))
rs_candidate$Percentage_of_CSA <- as.numeric(as.character(rs_candidate$Percentage_of_CSA))
str(rs_candidate)

resume <-
  rs_candidate %>%
  # filter(Number_QTN == "QTN_5" ) %>%  
  group_by(Scenario) %>%
  summarize(mean_scena_SR = round(mean(Response_to_selection, na.rm = FALSE),digits = 6),
            SD_scena_SR = round(sqrt(var(Response_to_selection, na.rm = FALSE)),digits = 6),
            SE_scena_SR = round(sqrt(var(Response_to_selection, na.rm = FALSE)) / sqrt(72),digits = 6),
            min_Int_95_SR = mean_scena_SR - 1.96 * SE_scena_SR,
            max_Int_95_SR = mean_scena_SR + 1.96 * SE_scena_SR,
            mean_scena_CSA = round(mean(Correctly_selected_animals.CSA., na.rm = FALSE),digits = 6),
            mean_scena_percentage_CSA = round(mean(Percentage_of_CSA, na.rm = FALSE),digits = 6),
            SD_scena_percentage_CSA = round(sqrt(var(Percentage_of_CSA, na.rm = FALSE)),digits = 6),
            SE_scena_percentage_CSA = round(sqrt(var(Percentage_of_CSA, na.rm = FALSE)) / sqrt(72),digits = 6),
            min_Int_95_percentage_CSA = mean_scena_percentage_CSA - 1.96 * SE_scena_percentage_CSA,
            max_Int_95_percentage_CSA = mean_scena_percentage_CSA + 1.96 * SE_scena_percentage_CSA
            )
resume <- as.data.frame(resume)
resume

write.table(resume,file = paste(pathway_2, "total_response_to_selection_summary_2021.txt",sep = ""),row.names = FALSE,quote = FALSE,sep = "\t")



